summaryrefslogtreecommitdiff
path: root/lib/rpmlib.h
diff options
context:
space:
mode:
authorjbj <devnull@localhost>2002-03-03 23:09:49 +0000
committerjbj <devnull@localhost>2002-03-03 23:09:49 +0000
commit2e2d1cad39b9bf8af73ec7b2c584236aabcdad14 (patch)
tree29804eebc51fc8e0143e62a7743f1c635b25820e /lib/rpmlib.h
parent48b19eaedae1d80691073730628c3ef806d6322d (diff)
downloadlibrpm-tizen-2e2d1cad39b9bf8af73ec7b2c584236aabcdad14.tar.gz
librpm-tizen-2e2d1cad39b9bf8af73ec7b2c584236aabcdad14.tar.bz2
librpm-tizen-2e2d1cad39b9bf8af73ec7b2c584236aabcdad14.zip
- add payload uncompressed size to signature to avoid rewriting header.
- drill header sha1 into signature parallel to header+payload md5. - mandatory "most effective" signature check on query/verify/install. - don't bother adding empty filemd's to index. - add Pubkey index, using signer id as binary key. - display pubkeys in hex when debugging db access. - retrieve pubkey(s) from rpmdb, not from detached signature file. - reapply Berkeley DB patch #4491. CVS patchset: 5341 CVS date: 2002/03/03 23:09:49
Diffstat (limited to 'lib/rpmlib.h')
-rw-r--r--lib/rpmlib.h13
1 files changed, 9 insertions, 4 deletions
diff --git a/lib/rpmlib.h b/lib/rpmlib.h
index 4b34fbbe7..1f7310969 100644
--- a/lib/rpmlib.h
+++ b/lib/rpmlib.h
@@ -228,6 +228,7 @@ typedef enum rpmTag_e {
/*@=enummemuse@*/
RPMTAG_SHA1HEADER = RPMTAG_SIG_BASE+9,
RPMTAG_PUBKEYS = RPMTAG_SIG_BASE+10,
+ RPMTAG_DSAHEADER = RPMTAG_SIG_BASE+11,
RPMTAG_NAME = 1000,
RPMTAG_VERSION = 1001,
@@ -773,9 +774,9 @@ typedef /*@abstract@*/ struct _rpmdbMatchIterator * rpmdbMatchIterator;
/*@modifies mi, fileSystem @*/;
/** \ingroup rpmdb
* Return join key for current position of rpm database iterator.
* @param mi rpm database iterator
* @return current join key
*/
unsigned int rpmdbGetIteratorOffset(/*@null@*/ rpmdbMatchIterator mi)
/*@*/;
@@ -1780,12 +1781,16 @@ typedef enum rpmEraseInterfaceFlags_e {
enum rpmtagSignature {
RPMSIGTAG_SIZE = 1000, /*!< Header+Payload size in bytes. */
/* the md5 sum was broken *twice* on big endian machines */
- RPMSIGTAG_LEMD5_1 = 1001, /*!< Broken MD5, take 1 */
+ RPMSIGTAG_LEMD5_1 = 1001, /*!< Broken MD5, take 1 @deprecated legacy. */
RPMSIGTAG_PGP = 1002, /*!< PGP 2.6.3 signature. */
- RPMSIGTAG_LEMD5_2 = 1003, /*!< Broken MD5, take 2 */
+ RPMSIGTAG_LEMD5_2 = 1003, /*!< Broken MD5, take 2 @deprecated legacy. */
RPMSIGTAG_MD5 = 1004, /*!< MD5 signature. */
RPMSIGTAG_GPG = 1005, /*!< GnuPG signature. */
RPMSIGTAG_PGP5 = 1006, /*!< PGP5 signature @deprecated legacy. */
+ RPMSIGTAG_PAYLOADSIZE = 1007,
+ /*!< uncompressed payload size in bytes. */
+ RPMSIGTAG_SHA1 = RPMTAG_SHA1HEADER, /*!< sha1 header digest. */
+ RPMSIGTAG_DSA = RPMTAG_DSAHEADER, /*!< DSA header signature. */
};
/**
@@ -773,9 +774,9 @@ typedef /*@abstract@*/ struct _rpmdbMatchIterator * rpmdbMatchIterator;
/*@modifies mi, fileSystem @*/;
/** \ingroup rpmdb
- * Return join key for current position of rpm database iterator.
+ * Return header join key for current position of rpm database iterator.
* @param mi rpm database iterator
@@ -773,9 +774,9 @@ typedef /*@abstract@*/ struct _rpmdbMatchIterator * rpmdbMatchIterator;
* @param mi rpm database iterator
- * @return current join key
+ * @return current header join key
*/
unsigned int rpmdbGetIteratorOffset(/*@null@*/ rpmdbMatchIterator mi)